[vlc-commits] commit: Remove useless indirection ( Rémi Denis-Courmont )

git at videolan.org git at videolan.org
Mon Mar 29 22:11:59 CEST 2010


vlc | branch: master | Rémi Denis-Courmont <remi at remlab.net> | Mon Mar 29 23:09:02 2010 +0300| [5960c93ca6f0252c9a99d0402e95b15472cd4a3a] | committer: Rémi Denis-Courmont 

Remove useless indirection

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=5960c93ca6f0252c9a99d0402e95b15472cd4a3a
---

 src/config/cmdline.c       |   10 +++++-----
 src/config/configuration.h |    2 +-
 src/libvlc.c               |    4 ++--
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/config/configuration.h b/src/config/configuration.h
index 6fae3c0..3e6e473 100644
--- a/src/config/configuration.h
+++ b/src/config/configuration.h
@@ -36,7 +36,7 @@ int  config_AutoSaveConfigFile( vlc_object_t * );
 
 void config_Free( module_t * );
 
-int config_LoadCmdLine   ( vlc_object_t *, int *, const char *[], bool );
+int config_LoadCmdLine   ( vlc_object_t *, int, const char *[], bool );
 int config_LoadConfigFile( vlc_object_t *, const char * );
 #define config_LoadCmdLine(a,b,c,d) config_LoadCmdLine(VLC_OBJECT(a),b,c,d)
 #define config_LoadConfigFile(a,b) config_LoadConfigFile(VLC_OBJECT(a),b)
diff --git a/src/libvlc.c b/src/libvlc.c
index 38e2b8b..716d25b 100644
--- a/src/libvlc.c
+++ b/src/libvlc.c
@@ -321,7 +321,7 @@ int libvlc_InternalInit( libvlc_int_t *p_libvlc, int i_argc,
      * options) */
     module_InitBank( p_libvlc );
 
-    if( config_LoadCmdLine( p_libvlc, &i_argc, ppsz_argv, true ) )
+    if( config_LoadCmdLine( p_libvlc, i_argc, ppsz_argv, true ) )
     {
         module_EndBank( p_libvlc, false );
         return VLC_EGENERIC;
@@ -537,7 +537,7 @@ int libvlc_InternalInit( libvlc_int_t *p_libvlc, int i_argc,
     /* config_LoadCmdLine(), DBus (below) and Win32-specific use vlc_optind,
      * vlc_optarg and vlc_optopt globals. This is not thread-safe!! */
 #warning BUG!
-    if( config_LoadCmdLine( p_libvlc, &i_argc, ppsz_argv, false ) )
+    if( config_LoadCmdLine( p_libvlc, i_argc, ppsz_argv, false ) )
     {
 #ifdef WIN32
         ShowConsole( false );



More information about the vlc-commits mailing list
diff --git a/src/config/cmdline.c b/src/config/cmdline.c
index 9174a4f..2f7e022 100644
--- a/src/config/cmdline.c
+++ b/src/config/cmdline.c
@@ -47,7 +47,7 @@
  * options used (ie. exported) by each module.
  *
  * @param p_this object to write command line options as variables to
  * @param pi_argc number of command line arguments [IN/OUT]
  * @param ppsz_args commandl ine arguments [IN/OUT]
  * @param b_ignore_errors whether to ignore parsing errors
  * @return 0 on success, -1 on error.
@@ -55,7 +55,7 @@
  * @warning This function is not re-entrant (because of getopt_long()).
  * It must be called with the module bank initialization global lock held.
  */
-int config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
+int config_LoadCmdLine( vlc_object_t *p_this, int i_argc,
                         const char *ppsz_argv[], bool b_ignore_errors )
 {
     int i_cmd, i_index, i_opts, i_shortopts, flag, i_verbose = 0;
@@ -101,7 +101,7 @@ int config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
      * us, ignoring the arity of the options */
     if( b_ignore_errors )
     {
-        argv_copy = (const char**)malloc( *pi_argc * sizeof(char *) );
+        argv_copy = (const char**)malloc( i_argc * sizeof(char *) );
         if( argv_copy == NULL )
         {
             free( psz_shortopts );
@@ -109,7 +109,7 @@ int config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
             module_list_free (list);
             return -1;
         }
-        memcpy( argv_copy, ppsz_argv, *pi_argc * sizeof(char *) );
+        memcpy( argv_copy, ppsz_argv, i_argc * sizeof(char *) );
         ppsz_argv = argv_copy;
     }
 
@@ -199,7 +199,7 @@ int config_LoadCmdLine( vlc_object_t *p_this, int *pi_argc,
      * Parse the command line options
      */
     vlc_optind = 0; /* set to 0 to tell GNU getopt to reinitialize */
-    while( ( i_cmd = vlc_getopt_long( *pi_argc, (char **)ppsz_argv,
+    while( ( i_cmd = vlc_getopt_long( i_argc, (char **)ppsz_argv,
                                       psz_shortopts,
                                       p_longopts, &i_index ) ) != -1 )
     {
@@ -47,7 +47,7 @@
  *
  * @param p_this object to write command line options as variables to
- * @param pi_argc number of command line arguments [IN/OUT]
+ * @param i_argc number of command line arguments
  * @param ppsz_args commandl ine arguments [IN/OUT]
  * @param b_ignore_errors whether to ignore parsing errors